@@ -1,6 +1,8 @@
 # This file is encoded in ShiftJIS.
 die "This file is not encoded in ShiftJIS.\n" if q{} ne "\x82\xa0";
 
+use Sjis;
+
 # Search pattern not terminated
 # uT[`p^[IȂv
 eval { /\/ };
@@ -13,7 +15,7 @@ else {
 
 __END__
 
-esjis.pl ŏXNvg̎sʂȉɂȂ邱Ƃ҂Ă
+Sjis.pm ŏXNvg̎sʂȉɂȂ邱Ƃ҂Ă
 
 1
 
