@@ -7,7 +7,8 @@ my @c = (
 );
 
 my $script = "chop\\chop.pl";
-open(SCRIPT,">$script") || die "Can't open file: $script\n";
+open(SCRIPT,">$script")      || die "Can't open file: $script\n";
+open(WANT,  ">$script.want") || die "Can't open file: $script.want\n";
 
 #----------------------------------------------------------------------------
 # chop
@@ -16,15 +17,18 @@ open(SCRIPT,">$script") || die "Can't open file: $script\n";
 for my $c (@c) {
     if ($c =~ /^['\\]$/) {
         print SCRIPT "\$_ = '\\", $c, "'; chop; print \$_, \"\\n\";\n";
+        print WANT "\n";
     }
     else {
         print SCRIPT "\$_ = '", $c, "'; chop; print \$_, \"\\n\";\n";
+        print WANT "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = '", chr($c1), chr($c2), "'; chop; print \$_, \"\\n\";\n";
+        print WANT "\n";
     }
 }
 
@@ -35,15 +39,18 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 for my $c (@c) {
     if ($c =~ /^['\\]$/) {
         print SCRIPT "\$_ = '\\", $c, "'; chop \$_; print \$_, \"\\n\";\n";
+        print WANT "\n";
     }
     else {
         print SCRIPT "\$_ = '", $c, "'; chop \$_; print \$_, \"\\n\";\n";
+        print WANT "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = '", chr($c1), chr($c2), "'; chop \$_; print \$_, \"\\n\";\n";
+        print WANT "\n";
     }
 }
 
@@ -54,15 +61,18 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 for my $c (@c) {
     if ($c =~ /^['\\]$/) {
         print SCRIPT "\$_ = '\\", $c, "'; chop(\$_); print \$_, \"\\n\";\n";
+        print WANT "\n";
     }
     else {
         print SCRIPT "\$_ = '", $c, "'; chop(\$_); print \$_, \"\\n\";\n";
+        print WANT "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = '", chr($c1), chr($c2), "'; chop(\$_); print \$_, \"\\n\";\n";
+        print WANT "\n";
     }
 }
 
@@ -73,15 +83,18 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 for my $c (@c) {
     if ($c =~ /^['\\]$/) {
         print SCRIPT "\@_ = (", "'\\", $c, "','\\", $c, "','\\", $c, "'", "); chop \@_; print \@_, \"\\n\";\n";
+        print WANT "\n";
     }
     else {
         print SCRIPT "\@_ = (", "'", $c, "','", $c, "','", $c, "'", "); chop \@_; print \@_, \"\\n\";\n";
+        print WANT "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\@_ = (", "'", chr($c1), chr($c2), "','", chr($c1), chr($c2), "','", chr($c1), chr($c2), "'", "); chop \@_; print \@_, \"\\n\";\n";
+        print WANT "\n";
     }
 }
 
@@ -92,18 +105,22 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 for my $c (@c) {
     if ($c =~ /^['\\]$/) {
         print SCRIPT "\@_ = (", "'\\", $c, "','\\", $c, "','\\", $c, "'", "); chop(\@_); print \@_, \"\\n\";\n";
+        print WANT "\n";
     }
     else {
         print SCRIPT "\@_ = (", "'", $c, "','", $c, "','", $c, "'", "); chop(\@_); print \@_, \"\\n\";\n";
+        print WANT "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\@_ = (", "'", chr($c1), chr($c2), "','", chr($c1), chr($c2), "','", chr($c1), chr($c2), "'", "); chop(\@_); print \@_, \"\\n\";\n";
+        print WANT "\n";
     }
 }
 
 close(SCRIPT);
+close(WANT);
 
 #----------------------------------------------------------------------------
